@@ -66,9 +66,9 @@ def parse_gate_info(lookup_key, flight):
 def convert_oag_status_to_normal_form(status):
     if status in ['scheduled', 'proposed']:
         return 'scheduled'
-    elif status in ['outgate', 'inair', 'notakeoffinfo']:
+    elif status in ['inair', 'notakeoffinfo']:
         return 'en route'
-    elif status in ['landed', 'ingate', 'pastflight']:
+    elif status in ['ingate', 'pastflight']:
         return 'arrived'
     else:
         return status
